@@ -19,10 +19,10 @@ History : (02/09/2010) First version.
 
 import math
 
-from PointClass import Point
-from AstroAngleInput import AstroAngleInput
-from CartesianCoordAmpRotoTranslation import CartesianCoordAmpRotoTranslation
-from InverseCartesianCoordAmpRotoTranslation import InverseCartesianCoordAmpRotoTranslation
+from .PointClass import Point
+from .AstroAngleInput import AstroAngleInput
+from .CartesianCoordAmpRotoTranslation import CartesianCoordAmpRotoTranslation
+from .InverseCartesianCoordAmpRotoTranslation import InverseCartesianCoordAmpRotoTranslation
 
 class Triangle:
     def __init__ (self, v0, v1, v2, atol=1.0):
