@@ -2,19 +2,19 @@
 
 Context : SRP
 Module  : Net.py
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 14/11/2010
+Date    : 20/05/2019
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
 Usage   : to be imported
 
 History : (14/11/2010) First version.
-
+        : (20/05/2019) Bug correction.
 """
 
-import os, smtplib
+import os, smtplib, socket
 
 
 
